@@ -46,6 +46,7 @@ pub type NameToolchainMap = BTreeMap<String, ToolchainMap>;
 #[derive(Debug, Default)]
 pub struct Dylint {
     pub all: bool,
+    pub bisect: bool,
     pub fix: bool,
     pub force: bool,
     pub isolate: bool,
@@ -67,6 +68,17 @@ pub struct Dylint {
 }
 
 pub fn run(opts: &Dylint) -> Result<()> {
+    if opts.bisect {
+        #[cfg(not(unix))]
+        bail!("`--bisect` is supported only on Unix platforms");
+
+        warn(opts, "`--bisect` is experimental");
+    }
+
+    if opts.bisect && opts.upgrade_path.is_none() {
+        bail!("`--bisect` can be used only with `--upgrade`");
+    }
+
     if opts.force && opts.upgrade_path.is_none() {
         bail!("`--force` can be used only with `--upgrade`");
     }
@@ -546,15 +558,13 @@ mod test {
         static ref NAME_TOOLCHAIN_MAP: NameToolchainMap = {
             examples::build().unwrap();
             let metadata = current_metadata().unwrap();
-            let dylint_library_path = if cfg!(coverage) {
-                metadata.target_directory.join("debug").into_os_string()
-            } else {
-                join_paths(&[
+            // smoelius: As of version 0.1.14, `cargo-llvm-cov` no longer sets `CARGO_TARGET_DIR`.
+            // So `dylint_library_path` no longer requires a `cfg!(coverage)` special case.
+            let dylint_library_path = join_paths(&[
                     metadata.target_directory.join("allow_clippy").join("debug"),
                     metadata.target_directory.join("examples").join("debug"),
                 ])
-                .unwrap()
-            };
+                .unwrap();
             set_var(env::DYLINT_LIBRARY_PATH, dylint_library_path);
             name_toolchain_map(&Dylint {
                 no_metadata: true,
